@@ -14,7 +14,7 @@ mod msg_id;
 #[cfg(not(feature = "client-only"))]
 pub mod node;
 pub mod section_info;
-mod serialisation;
+pub mod serialisation;
 
 pub use self::{
     errors::{Error, Result},
@@ -90,6 +90,32 @@ impl MessageType {
         }
     }
 
+    pub fn to_wire_msg(&self) -> Result<WireMsg> {
+        match self {
+            Self::SectionInfo { msg, dest_info } => {
+                WireMsg::new_section_info_msg(msg, dest_info.dest, dest_info.dest_section_pk)
+            }
+            Self::Client { msg, dest_info } => {
+                WireMsg::new_client_msg(msg, dest_info.dest, dest_info.dest_section_pk)
+            }
+            #[cfg(not(feature = "client-only"))]
+            Self::Routing { msg, dest_info } => {
+                WireMsg::new_routing_msg(msg, dest_info.dest, dest_info.dest_section_pk)
+            }
+            #[cfg(not(feature = "client-only"))]
+            Self::Node {
+                msg,
+                dest_info,
+                src_section_pk,
+            } => WireMsg::new_node_msg(
+                msg,
+                dest_info.dest,
+                dest_info.dest_section_pk,
+                *src_section_pk,
+            ),
+        }
+    }
+
     pub fn update_dest_info(&mut self, dest_pk: Option<PublicKey>, dest: Option<XorName>) {
         #[cfg(not(feature = "client-only"))]
         match self {
